@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-from python_qt_binding.QtQml import qmlRegisterType, qmlRegisterSingletonType
+from qtpy.QtQml import qmlRegisterType, qmlRegisterSingletonType
 
 from .projectbrowser import ProjectBrowser
 from .filewatcher import FileWatcher
